@@ -20,6 +20,15 @@
 
 #include "dialog.h"
 
+static const char* const *the_items;
+
+static void okayed(GtkWidget *w, int i)
+{
+  write(2, the_items[2*i], strlen(the_items[2*i]));
+  write(2, "\n", 1);
+  exit(i);
+}
+
 static int menu_width, tag_x, item_x;
 
 /*
@@ -68,6 +77,8 @@ int dialog_menu(const char *title, const char *prompt, int height, int width,
 		GtkWidget *butframe;
 		GtkWidget *butbox;
 		
+		the_items = items;
+
 		gnome_dialog_set_close(GNOME_DIALOG(w), TRUE);
 		gtk_window_set_title(GTK_WINDOW(w), title);
 		
@@ -79,8 +90,8 @@ int dialog_menu(const char *title, const char *prompt, int height, int width,
 		butbox=gtk_vbox_new(FALSE, 0);
 		butframe=gtk_frame_new("");
 		
-		gtk_container_border_width(GTK_CONTAINER(butframe), GNOME_PAD);
-		gtk_container_border_width(GTK_CONTAINER(butbox), GNOME_PAD);
+		gtk_container_set_border_width(GTK_CONTAINER(butframe), GNOME_PAD);
+		gtk_container_set_border_width(GTK_CONTAINER(butbox), GNOME_PAD);
 		gtk_frame_set_shadow_type(GTK_FRAME(butframe), GTK_SHADOW_ETCHED_IN);
 				
 		
@@ -93,6 +104,8 @@ int dialog_menu(const char *title, const char *prompt, int height, int width,
 			but=gtk_button_new_with_label(p);
 			g_free(p);
 			gtk_box_pack_start(GTK_BOX(butbox), but, TRUE, TRUE, 0);
+			gtk_signal_connect(GTK_OBJECT(but), "clicked",
+			GTK_SIGNAL_FUNC(okayed), GUINT_TO_POINTER(i));
 		}
 		
 		gtk_container_add(GTK_CONTAINER(butframe), butbox);
@@ -103,7 +116,7 @@ int dialog_menu(const char *title, const char *prompt, int height, int width,
 		gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(w)->vbox), 
 			hbox,
 			TRUE, TRUE, GNOME_PAD);
-		gtk_window_position(GTK_WINDOW(w), GTK_WIN_POS_CENTER);
+		gtk_window_set_position(GTK_WINDOW(w), GTK_WIN_POS_CENTER);
 		gtk_widget_show_all(w);
 		gtk_main();
 		return;
