@@ -135,13 +135,11 @@ int main ( int argc, char ** argv )
   int i;
   gchar * config_string;
 
-  argp_program_version = VERSION;
-
   /* Initialize the i18n stuff */
   bindtextdomain (PACKAGE, GNOMELOCALEDIR);
   textdomain (PACKAGE);
 
-  gnome_init (APPNAME, 0, argc, argv, 0, 0);
+  gnome_init (APPNAME, VERSION, argc, argv);
 
   i = 0;
   while (i < 7) {
@@ -174,7 +172,7 @@ static void popup_main_dialog()
 
   d = gnome_dialog_new( _("Shutdown or Reboot"), GNOME_STOCK_BUTTON_OK,
 			GNOME_STOCK_BUTTON_CANCEL, NULL );
-  gnome_dialog_set_destroy( GNOME_DIALOG(d), TRUE );
+  gnome_dialog_set_close( GNOME_DIALOG(d), TRUE );
   /*  gnome_dialog_set_modal( GNOME_DIALOG(d) ); */
 
   notebook = gtk_notebook_new();
@@ -263,7 +261,6 @@ static void prepare_easy_vbox(GtkWidget * dialog, GtkWidget * vbox)
                       help_box, TRUE, TRUE, 0);
 
   button = gnome_stock_button(GNOME_STOCK_BUTTON_HELP);
-  gtk_widget_set_usize(button, GNOME_BUTTON_WIDTH, GNOME_BUTTON_HEIGHT);
   gtk_box_pack_end(GTK_BOX(help_box), button, FALSE, FALSE, 0);
   
   gtk_signal_connect( GTK_OBJECT(button), "clicked",
@@ -301,13 +298,11 @@ static void prepare_advanced_vbox(GtkWidget * vbox)
   /* Fixme these should be stock buttons */
 
   button = gnome_stock_or_ordinary_button("Preferences");
-  gtk_widget_set_usize(button, GNOME_BUTTON_WIDTH, GNOME_BUTTON_HEIGHT);
   gtk_box_pack_end(GTK_BOX(box), button, FALSE, FALSE, GNOME_PAD); 
   gtk_signal_connect(GTK_OBJECT(button), "clicked",
                      GTK_SIGNAL_FUNC(popup_preferences), NULL);
 
   button = gnome_stock_or_ordinary_button("About");
-  gtk_widget_set_usize(button, GNOME_BUTTON_WIDTH, GNOME_BUTTON_HEIGHT);
   gtk_box_pack_end(GTK_BOX(box), button, FALSE, FALSE, GNOME_PAD); 
   gtk_signal_connect(GTK_OBJECT(button), "clicked",
                      GTK_SIGNAL_FUNC(popup_about), NULL);
@@ -358,7 +353,6 @@ static void popup_preferences()
 
   /* Put in a "revert to defaults" button */
   button = gtk_button_new_with_label(_("Revert to Defaults"));
-  gtk_widget_set_usize(button, GNOME_BUTTON_WIDTH, GNOME_BUTTON_HEIGHT);
   /* Attach to the last of 8 table slots in col. 2 */
   gtk_table_attach(GTK_TABLE(table), button, col, col+1,row+1, row+2, 
                    0, 0, GNOME_PAD_SMALL, GNOME_PAD_SMALL);
@@ -420,8 +414,8 @@ static void popup_not_in_path(const gchar * command)
 static void popup_about()
 {
   GtkWidget * ga;
-  gchar * authors[] = { "Havoc Pennington <hp@pobox.com>",
-                        NULL };
+  static const char * authors[] = { "Havoc Pennington <hp@pobox.com>",
+                                    NULL };
 
   ga = gnome_about_new (APPNAME,
                         VERSION, 
@@ -459,7 +453,7 @@ static void popup_confirm(void)
 
   /* Has to be or the runlevel requested
      could change in the background */
-  gnome_dialog_set_modal(GNOME_DIALOG(d)); 
+  gtk_window_set_modal(GTK_WINDOW(d),TRUE); 
 
   gtk_signal_connect(GTK_OBJECT(d), "clicked",
                      GTK_SIGNAL_FUNC(confirm_cb), NULL);
