@@ -21,6 +21,7 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <errno.h>
 
 #include <sys/utsname.h>
 #include <unistd.h>
@@ -69,13 +70,11 @@ GtkWidget * popup = NULL;
 
 int main ( int argc, char ** argv )
 {
-  argp_program_version = VERSION;
-
   /* Initialize the i18n stuff */
   bindtextdomain (PACKAGE, GNOMELOCALEDIR);
   textdomain (PACKAGE);
 
-  gnome_init (APPNAME, 0, argc, argv, 0, 0);
+  gnome_init (APPNAME, VERSION, argc, argv);
 
   load_system_info();
 #if HAVE_LIBGTOP
@@ -383,7 +382,7 @@ static void do_logo_box(GtkWidget * box)
     
 	im = gdk_imlib_load_image (s);
 
-    gnome_canvas_set_size (GNOME_CANVAS (pixmap), im->rgb_width, im->rgb_height);
+    gtk_widget_set_usize (pixmap, im->rgb_width, im->rgb_height);
     gnome_canvas_set_scroll_region (GNOME_CANVAS (pixmap), 0, 0, 
                                     im->rgb_width, im->rgb_height);
 
@@ -488,21 +487,25 @@ static void do_logo_box(GtkWidget * box)
 static void do_list_box(GtkWidget * box)
 {
   GtkCList * list;
+  GtkWidget *sw;
   const gchar * titles[] = { _("Category"), _("Your System") };
 
   list = GTK_CLIST(create_clist(titles));
-
+  sw = gtk_scrolled_window_new (NULL, NULL);
+  
   gtk_clist_freeze(list); /* does this matter if we haven't shown yet? */
 
   gtk_clist_set_border(list, GTK_SHADOW_OUT);
   /* Fixme, eventually you might could select an item 
      for cut and paste, or some other effect. */
   gtk_clist_set_selection_mode(list, GTK_SELECTION_BROWSE);
-  gtk_clist_set_policy(list, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
+  gtk_container_add (GTK_CONTAINER (sw), GTK_WIDGET (list));
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  gtk_widget_show (GTK_WIDGET (list));
   gtk_clist_column_titles_passive(list);
 
-  do_popup(GTK_WIDGET(list));
+  do_popup(GTK_WIDGET(sw));
   gtk_widget_set_events(GTK_WIDGET(list), GDK_BUTTON_PRESS_MASK);
   gtk_signal_connect(GTK_OBJECT(list), "button_press_event",
                      GTK_SIGNAL_FUNC(list_clicked_cb), NULL);
@@ -511,7 +514,7 @@ static void do_list_box(GtkWidget * box)
 
   gtk_clist_thaw(list);
 
-  gtk_container_add(GTK_CONTAINER(box), GTK_WIDGET(list));
+  gtk_container_add(GTK_CONTAINER(box), GTK_WIDGET(sw));
 }
 
 static void do_popup(GtkWidget * clist)
